@@ -131,6 +131,7 @@ void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
 
     connect(backend, &AbstractResourcesBackend::fetchingChanged, this, &ResourcesModel::callerFetchingChanged);
     connect(backend, &AbstractResourcesBackend::allDataChanged, this, &ResourcesModel::updateCaller);
+    connect(backend, &AbstractResourcesBackend::resourcesChanged, this, &ResourcesModel::emitResourceChanges);
     connect(backend, &AbstractResourcesBackend::updatesCountChanged, this, &ResourcesModel::updatesCountChanged);
     connect(backend, &AbstractResourcesBackend::searchInvalidated, this, &ResourcesModel::searchInvalidated);
 
@@ -163,8 +164,7 @@ QModelIndex ResourcesModel::resourceIndex(AbstractResource* res) const
         else {
             Q_ASSERT(!m_backends[i]->isFetching());
             int pos = m_resources[i].indexOf(res);
-            Q_ASSERT(pos>=0);
-            return index(row+pos);
+            return pos>=0 ? index(row+pos) : QModelIndex();
         }
     }
 
@@ -307,7 +307,7 @@ void ResourcesModel::resetBackend(AbstractResourcesBackend* backend)
     }
 }
 
-void ResourcesModel::updateCaller()
+void ResourcesModel::updateCaller(const QVector<QByteArray>& properties)
 {
     AbstractResourcesBackend* backend = qobject_cast<AbstractResourcesBackend*>(sender());
     QVector<QVector<AbstractResource*>>::iterator backendsResources;
@@ -315,7 +315,25 @@ void ResourcesModel::updateCaller()
     if (backendsResources->isEmpty())
         return;
     
-    emit dataChanged(index(before), index(before+backendsResources->size()-1));
+    emit dataChanged(index(before), index(before+backendsResources->size()-1), propertiesToRoles(properties));
+}
+
+QVector<int> ResourcesModel::propertiesToRoles(const QVector<QByteArray>& properties) const
+{
+    QVector<int> roles;
+    roles.reserve(properties.size());
+    std::transform(properties.cbegin(), properties.cend(), roles.begin(), [this](const QByteArray& arr) { return roleNames().key(arr, -1); });
+    roles.removeAll(-1);
+    return roles;
+}
+
+void ResourcesModel::emitResourceChanges(AbstractResource* resource, const QVector<QByteArray> &properties)
+{
+    const QModelIndex idx = resourceIndex(resource);
+    if (!idx.isValid())
+        return;
+
+    emit dataChanged(idx, idx, propertiesToRoles(properties));
 }
 
 QVector< AbstractResourcesBackend* > ResourcesModel::backends() const
@@ -367,12 +385,6 @@ void ResourcesModel::removeApplication(AbstractResource* app)
     app->backend()->removeApplication(app);
 }
 
-void ResourcesModel::cancelTransaction(AbstractResource* app)
-{
-    Q_ASSERT(!isFetching());
-    app->backend()->cancelTransaction(app);
-}
-
 QMap<int, QVariant> ResourcesModel::itemData(const QModelIndex& index) const
 {
     QMap<int, QVariant> ret;
@@ -443,19 +455,19 @@ QList<QAction*> ResourcesModel::messageActions() const
     return ret;
 }
 
-QVariantList ResourcesModel::messageActionsVariant() const
-{
-    QVariantList ret;
-    QList<QAction*> actions = messageActions();
-    ret.reserve(actions.count());
-
-    foreach(QAction* action, actions) {
-        ret += QVariant::fromValue<QObject*>(action);
-    }
-    return ret;
-}
-
 bool ResourcesModel::isBusy() const
 {
     return TransactionModel::global()->rowCount() > 0;
 }
+
+bool ResourcesModel::isExtended(const QString& id)
+{
+    auto resourceExtends = [id](AbstractResource* res) {return res->extends().contains(id); };
+    bool ret = false;
+    foreach (const QVector<AbstractResource*> & backend, m_resources) {
+        ret = std::find_if(backend.cbegin(), backend.cend(), resourceExtends) != backend.cend();
+        if (ret)
+            break;
+    }
+    return ret;
+}
